==> nextcloud-25.0.11.tgz: nextcloud/apps/viewer/l10n/fa.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Simple file viewer with slideshow for media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!",
    "Your browser does not support audio." : "Your browser does not support audio.",
    "Error loading {name}" : "Error loading {name}",
    "Image saved" : "تصویر ذخیره شد",
    "Error saving image" : "Error saving image",
    "Unsaved changes" : "Unsaved changes",
    "Drop changes" : "Drop changes",
    "Your browser does not support videos." : "Your browser does not support videos.",
    "Edit" : "ویرایش",
    "Exit full screen" : "Exit full screen",
    "Full screen" : "Full screen",
    "Open sidebar" : "باز کردن نوار کناری",
    "Download" : "بارگیری",
    "Delete" : "حذف",
    "This file no longer exists" : "This file no longer exists",
    "There is no plugin available to display this file type" : "There is no plugin available to display this file type",
    "View" : "نمایش",
    "Name" : "نام",
    "Save" : "ذخیره",
    "Save as" : "Save as",
    "Back" : "بازگشت",
    "Loading …" : "بارگذاری …",
    "Reset" : "بازنشاندن",
    "All changes will be lost." : "All changes will be lost.",
    "Are you sure you want to continue?" : "Are you sure you want to continue?",
    "Cancel" : "لغو",
    "Continue" : "ادامه دادن",
    "Undo" : "برگرداندن",
    "Redo" : "Redo",
    "Show original image" : "Show original image",
    "Zoom in" : "Zoom in",
    "Zoom out" : "Zoom out",
    "Toggle zoom menu" : "Toggle zoom menu",
    "Adjust" : "Adjust",
    "Fine-tune" : "Fine-tune",
    "Filters" : "Filters",
    "Watermark" : "Watermark",
    "Draw" : "Draw",
    "Resize" : "Resize",
    "Invalid image." : "Invalid image.",
    "Error while uploading the image." : "Error while uploading the image.",
    "are not images" : "are not images",
    "is not an image" : "is not an image",
    "to be uploaded" : "to be uploaded",
    "Crop" : "Crop",
    "Original" : "اصلی",
    "Custom" : "Custom",
    "Square" : "Square",
    "Landscape" : "Landscape",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Classic TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Arrow",
    "Blur" : "Blur",
    "Brightness" : "Brightness",
    "Contrast" : "Contrast",
    "Un-flip X" : "Un-flip X",
    "Flip X" : "Flip X",
    "Un-flip Y" : "Un-flip Y",
    "Flip Y" : "Flip Y",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturation",
    "Value" : "ارزش",
    "Image" : "Image",
    "Importing …" : "Importing …",
    "+ Add image" : "+ Add image",
    "Line" : "Line",
    "Pen" : "Pen",
    "Polygon" : "Polygon",
    "Sides" : "Sides",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Corner Radius",
    "Width in pixels" : "Width in pixels",
    "Height in pixels" : "Height in pixels",
    "Toggle ratio lock" : "Toggle ratio lock",
    "Reset to original image size" : "Reset to original image size",
    "Rotate" : "Rotate",
    "Text" : "متن",
    "Text spacing" : "Text spacing",
    "Text alignment" : "Text alignment",
    "Font family" : "Font family",
    "Size" : "اندازه",
    "Letter spacing" : "Letter spacing",
    "Line height" : "Line height",
    "Warmth" : "Warmth",
    "+ Add watermark" : "+ Add watermark",
    "Choose watermark type" : "Choose watermark type",
    "Upload watermark" : "Upload watermark",
    "Add as text" : "Add as text",
    "Padding" : "Padding",
    "Shadow" : "Shadow",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacity",
    "Position" : "Position",
    "Stroke" : "Stroke",
    "Save image as" : "Save image as",
    "Extension" : "گسترش",
    "Name is required." : "نام الزامی است",
    "Quality" : "Quality",
    "Saved image size (width x height)" : "Saved image size (width x height)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Note that the selected crop area is lower than the applied resize which might cause quality decrease",
    "Actual size (100%)" : "Actual size (100%)",
    "Fit size" : "Fit size",
    "\"{fileName}\"" : "\"{fileName}\""
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/viewer/l10n/fa.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Viewer",
    "Simple file viewer with slideshow for media" : "Simple file viewer with slideshow for media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!",
    "Your browser does not support audio." : "Your browser does not support audio.",
    "Error loading {name}" : "Error loading {name}",
    "Image saved" : "تصویر ذخیره شد",
    "Error saving image" : "Error saving image",
    "Unsaved changes" : "Unsaved changes",
    "Drop changes" : "Drop changes",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Your browser does not support videos.",
    "Edit" : "ویرایش",
    "Exit full screen" : "Exit full screen",
    "Full screen" : "Full screen",
    "Open sidebar" : "باز کردن نوار کناری",
    "Download" : "بارگیری",
    "Delete" : "حذف",
    "This file no longer exists" : "This file no longer exists",
    "There is no plugin available to display this file type" : "There is no plugin available to display this file type",
    "View" : "نمایش",
    "Name" : "نام",
    "Save" : "ذخیره",
    "Save as" : "Save as",
    "Back" : "بازگشت",
    "Loading …" : "بارگذاری …",
    "Reset" : "بازنشاندن",
    "All changes will be lost." : "All changes will be lost.",
    "Are you sure you want to continue?" : "Are you sure you want to continue?",
    "Cancel" : "لغو",
    "Apply" : "اعمال",
    "Warning" : "هشدار",
    "Confirm" : "تأیید",
    "Discard changes" : "Discard changes",
    "Undo" : "برگرداندن",
    "Redo" : "Redo",
    "Show original image" : "Show original image",
    "Zoom in" : "Zoom in",
    "Zoom out" : "Zoom out",
    "Toggle zoom menu" : "Toggle zoom menu",
    "Adjust" : "Adjust",
    "Fine-tune" : "Fine-tune",
    "Filters" : "Filters",
    "Watermark" : "Watermark",
    "Draw" : "Draw",
    "Resize" : "Resize",
    "Invalid image." : "Invalid image.",
    "Error while uploading the image." : "Error while uploading the image.",
    "are not images" : "are not images",
    "is not an image" : "is not an image",
    "to be uploaded" : "to be uploaded",
    "Crop" : "Crop",
    "Original" : "اصلی",
    "Custom" : "Custom",
    "Square" : "Square",
    "Landscape" : "Landscape",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Classic TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Arrow",
    "Blur" : "Blur",
    "Brightness" : "Brightness",
    "Contrast" : "Contrast",
    "Un-flip X" : "Un-flip X",
    "Flip X" : "Flip X",
    "Un-flip Y" : "Un-flip Y",
    "Flip Y" : "Flip Y",
    "HSV" : "HSV",
    "Hue" : "Hue",
    "Saturation" : "Saturation",
    "Value" : "ارزش",
    "Image" : "Image",
    "Importing …" : "Importing …",
    "+ Add image" : "+ Add image",
    "Line" : "Line",
    "Pen" : "Pen",
    "Polygon" : "Polygon",
    "Sides" : "Sides",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Corner Radius",
    "Width in pixels" : "Width in pixels",
    "Height in pixels" : "Height in pixels",
    "Toggle ratio lock" : "Toggle ratio lock",
    "Reset to original image size" : "Reset to original image size",
    "Rotate" : "Rotate",
    "Text" : "متن",
    "Text spacing" : "Text spacing",
    "Text alignment" : "Text alignment",
    "Font family" : "Font family",
    "Size" : "اندازه",
    "Letter spacing" : "Letter spacing",
    "Line height" : "Line height",
    "Warmth" : "Warmth",
    "+ Add watermark" : "+ Add watermark",
    "Choose watermark type" : "Choose watermark type",
    "Upload watermark" : "Upload watermark",
    "Add as text" : "Add as text",
    "Padding" : "Padding",
    "Shadow" : "Shadow",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacity",
    "Position" : "Position",
    "Stroke" : "Stroke",
    "Save image as" : "Save image as",
    "Extension" : "گسترش",
    "Name is required." : "نام الزامی است",
    "Quality" : "Quality",
    "Saved image size (width x height)" : "Saved image size (width x height)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Note that the selected crop area is lower than the applied resize which might cause quality decrease",
    "Actual size (100%)" : "Actual size (100%)",
    "Fit size" : "Fit size",
    "Menu" : "منو",
    "Height" : "Height"
},
"nplurals=2; plural=(n > 1);");
